@@ -1,19 +1,17 @@
 import csv
-import os
 import sys
 import threading
 import traceback
 from io import StringIO
-from zipfile import ZipFile
 
-from flask import g, request
+from flask import g, redirect, request
 
 from sqlalchemy import or_, select
 from sqlalchemy.orm import joinedload
 from sqlalchemy.sql.expression import null, true
 
-import chellow.dloads
-from chellow.models import Era, Session, Site, SiteEra, Supply, User
+from chellow.dloads import open_file
+from chellow.models import Era, RSession, Site, SiteEra, Supply, User
 from chellow.utils import (
     csv_make_val,
     ct_datetime,
@@ -24,7 +22,6 @@ from chellow.utils import (
     to_ct,
     to_utc,
 )
-from chellow.views import chellow_redirect
 
 
 def _write_row(writer, titles, vals, total):
@@ -110,9 +107,8 @@ def _process_site(sess, zf, site, start_date, finish_date, typ):
 def none_content(site_codes, typ, start_date, finish_date, user_id, file_name):
     zf = None
     try:
-        with Session() as sess:
-            user = User.get_by_id(sess, user_id)
-            running_name, finished_name = chellow.dloads.make_names(file_name, user)
+        with RSession() as rsess:
+            user = User.get_by_id(rsess, user_id)
             sites_q = (
                 select(Site)
                 .join(SiteEra)
@@ -127,13 +123,13 @@ def none_content(site_codes, typ, start_date, finish_date, user_id, file_name):
             if site_codes is not None:
                 sites_q = sites_q.where(Site.code.in_(site_codes))
 
-            zf = ZipFile(running_name, "w")
+            zf = open_file(file_name, user, mode="w", is_zip=True)
 
-            for site in sess.execute(sites_q).scalars():
-                _process_site(sess, zf, site, start_date, finish_date, typ)
+            for site in rsess.execute(sites_q).scalars():
+                _process_site(rsess, zf, site, start_date, finish_date, typ)
 
                 # Avoid long-running transaction
-                sess.rollback()
+                rsess.rollback()
     except BaseException:
         msg = traceback.format_exc()
         sys.stderr.write(msg)
@@ -141,19 +137,17 @@ def none_content(site_codes, typ, start_date, finish_date, user_id, file_name):
     finally:
         if zf is not None:
             zf.close()
-            os.rename(running_name, finished_name)
 
 
 def site_content(site_id, start_date, finish_date, user_id, file_name):
     f = None
     try:
-        with Session() as sess:
-            user = User.get_by_id(sess, user_id)
-            running_name, finished_name = chellow.dloads.make_names(file_name, user)
-            f = open(running_name, mode="w", newline="")
+        with RSession() as rsess:
+            user = User.get_by_id(rsess, user_id)
+            f = open_file(file_name, user, mode="w", newline="")
             writer = csv.writer(f, lineterminator="\n")
-            site = Site.get_by_id(sess, site_id)
-            sites = sess.query(Site).filter(Site.id == site_id)
+            site = Site.get_by_id(rsess, site_id)
+            sites = rsess.query(Site).filter(Site.id == site_id)
             start_date_str = hh_format(start_date)
             finish_date_str = hh_format(finish_date)
 
@@ -174,12 +168,12 @@ def site_content(site_id, start_date, finish_date, user_id, file_name):
                 )
                 associates = " ".join(
                     s.code
-                    for s in site.find_linked_sites(sess, start_date, finish_date)
+                    for s in site.find_linked_sites(rsess, start_date, finish_date)
                 )
                 source_codes = set()
                 gen_types = set()
                 for supply in (
-                    sess.query(Supply)
+                    rsess.query(Supply)
                     .join(Era)
                     .join(SiteEra)
                     .filter(
@@ -200,7 +194,7 @@ def site_content(site_id, start_date, finish_date, user_id, file_name):
                 source_codes_str = ", ".join(sorted(source_codes))
                 gen_types_str = ", ".join(sorted(gen_types))
                 vals = None
-                for hh in site.hh_data(sess, start_date, finish_date):
+                for hh in site.hh_data(rsess, start_date, finish_date):
                     hh_start_ct = to_ct(hh["start_date"])
                     if hh_start_ct.hour == 0 and hh_start_ct.minute == 0:
                         if vals is not None:
@@ -229,7 +223,6 @@ def site_content(site_id, start_date, finish_date, user_id, file_name):
     finally:
         if f is not None:
             f.close()
-            os.rename(running_name, finished_name)
 
 
 def do_post(sess):
@@ -247,7 +240,7 @@ def do_post(sess):
         file_name = f"sites_hh_data_{site_id}_{finish_date_str}.csv"
         args = site_id, start_date, finish_date, g.user.id, file_name
         threading.Thread(target=site_content, args=args).start()
-        return chellow_redirect("/downloads", 303)
+        return redirect("/downloads", 303)
     else:
         typ = req_str("type")
         site_codes_str = req_str("site_codes")
@@ -258,4 +251,4 @@ def do_post(sess):
         file_name = f"sites_hh_data_{finish_date_str}_filter.zip"
         args = site_codes, typ, start_date, finish_date, g.user.id, file_name
         threading.Thread(target=none_content, args=args).start()
-        return chellow_redirect("/downloads", 303)
+        return redirect("/downloads", 303)
