@@ -1,50 +1,58 @@
 import csv
-import os
 import threading
 import traceback
 
-from flask import g, request
+from flask import g, redirect, request
 
-from sqlalchemy import and_, or_
+from sqlalchemy import and_, or_, select
 from sqlalchemy.orm import joinedload
 
 from werkzeug.exceptions import BadRequest
 
-import chellow.dloads
-from chellow.models import Batch, Bill, BillType, Era, RegisterRead, Session, Supply
+from chellow.dloads import open_file
+from chellow.models import (
+    Batch,
+    Bill,
+    BillType,
+    Era,
+    RSession,
+    RegisterRead,
+    Supply,
+    User,
+)
 from chellow.utils import c_months_u, csv_make_val, req_int
-from chellow.views import chellow_redirect
 
 
-def content(year, month, months, supply_id, user):
+def content(year, month, months, supply_id, user_id):
     f = None
     try:
-        with Session() as sess:
-            running_name, finished_name = chellow.dloads.make_names(
-                "register_reads.csv", user
-            )
-            f = open(running_name, mode="w", newline="")
+        with RSession() as sess:
+            user = User.get_by_id(sess, user_id)
+
+            f = open_file("register_reads.csv", user, mode="w", newline="")
             w = csv.writer(f, lineterminator="\n")
             titles = (
-                "Duration Start",
-                "Duration Finish",
-                "Supply Id",
-                "Import MPAN Core",
-                "Export MPAN Core",
-                "Batch Reference",
-                "Bill Id",
-                "Bill Reference",
-                "Bill Issue Date",
-                "Bill Type",
-                "Register Read Id",
-                "TPR",
-                "Coefficient",
-                "Previous Read Date",
-                "Previous Read Value",
-                "Previous Read Type",
-                "Present Read Date",
-                "Present Read Value",
-                "Present Read Type",
+                "duration_start",
+                "duration_finish",
+                "site_code",
+                "site_name",
+                "supply_id",
+                "imp_mpan_core",
+                "exp_mpan_core",
+                "batch_reference",
+                "bill_id",
+                "bill_reference",
+                "bill_issue_date",
+                "bill_type",
+                "register_read_id",
+                "tpr",
+                "coefficient",
+                "prev_read_date",
+                "prev_read_value",
+                "prev_read_type",
+                "pres_read_date",
+                "pres_read_value",
+                "pres_read_type",
             )
             w.writerow(titles)
 
@@ -54,10 +62,10 @@ def content(year, month, months, supply_id, user):
             start_date, finish_date = month_pairs[0][0], month_pairs[-1][-1]
 
             supplies = (
-                sess.query(Supply)
+                select(Supply)
                 .join(Bill)
                 .join(RegisterRead)
-                .filter(
+                .where(
                     or_(
                         and_(
                             RegisterRead.present_date >= start_date,
@@ -69,18 +77,18 @@ def content(year, month, months, supply_id, user):
                         ),
                     )
                 )
-                .order_by(Bill.supply_id)
+                .order_by(Supply.id)
                 .distinct()
             )
 
             if supply_id is not None:
                 supply = Supply.get_by_id(sess, supply_id)
-                supplies = supplies.filter(Bill.supply == supply)
+                supplies = supplies.where(Supply.id == supply.id)
 
-            for supply in supplies:
+            for supply in sess.scalars(supplies):
                 supply_id = supply.id
-                for bill, batch, bill_type in (
-                    sess.query(Bill, Batch, BillType)
+                for bill, batch, bill_type in sess.execute(
+                    select(Bill, Batch, BillType)
                     .join(Batch)
                     .join(BillType)
                     .join(RegisterRead)
@@ -111,6 +119,8 @@ def content(year, month, months, supply_id, user):
                         else:
                             era = eras[-1]
 
+                    site = era.get_physical_site(sess)
+
                     for read in (
                         sess.query(RegisterRead)
                         .filter(
@@ -132,28 +142,30 @@ def content(year, month, months, supply_id, user):
                             joinedload(RegisterRead.present_type),
                         )
                     ):
-                        vals = [
-                            start_date,
-                            finish_date,
-                            supply_id,
-                            era.imp_mpan_core,
-                            era.exp_mpan_core,
-                            batch.reference,
-                            bill.id,
-                            bill.reference,
-                            bill.issue_date,
-                            bill_type.code,
-                            read.id,
-                            "md" if read.tpr is None else read.tpr.code,
-                            read.coefficient,
-                            read.previous_date,
-                            read.previous_value,
-                            read.previous_type.code,
-                            read.present_date,
-                            read.present_value,
-                            read.present_type.code,
-                        ]
-                        w.writerow(csv_make_val(v) for v in vals)
+                        vals = {
+                            "duration_start": start_date,
+                            "duration_finish": finish_date,
+                            "site_code": site.code,
+                            "site_name": site.name,
+                            "supply_id": supply_id,
+                            "imp_mpan_core": era.imp_mpan_core,
+                            "exp_mpan_core": era.exp_mpan_core,
+                            "batch_reference": batch.reference,
+                            "bill_id": bill.id,
+                            "bill_reference": bill.reference,
+                            "bill_issue_date": bill.issue_date,
+                            "bill_type": bill_type.code,
+                            "register_read_id": read.id,
+                            "tpr": "md" if read.tpr is None else read.tpr.code,
+                            "coefficient": read.coefficient,
+                            "prev_read_date": read.previous_date,
+                            "prev_read_value": read.previous_value,
+                            "prev_read_type": read.previous_type.code,
+                            "pres_read_date": read.present_date,
+                            "pres_read_value": read.present_value,
+                            "pres_read_type": read.present_type.code,
+                        }
+                        w.writerow(csv_make_val(vals.get(t)) for t in titles)
 
                     # Avoid a long-running transaction
                     sess.rollback()
@@ -162,11 +174,11 @@ def content(year, month, months, supply_id, user):
         w.writerow([e.description])
     except BaseException:
         msg = traceback.format_exc()
+        print(msg)
         f.write(msg)
     finally:
         if f is not None:
             f.close()
-            os.rename(running_name, finished_name)
 
 
 def do_get(sess):
@@ -174,6 +186,6 @@ def do_get(sess):
     month = req_int("end_month")
     months = req_int("months")
     supply_id = req_int("supply_id") if "supply_id" in request.values else None
-    args = (year, month, months, supply_id, g.user)
+    args = year, month, months, supply_id, g.user.id
     threading.Thread(target=content, args=args).start()
-    return chellow_redirect("/downloads", 303)
+    return redirect("/downloads", 303)
