@@ -1,17 +1,16 @@
 import csv
-import os
 import sys
 import threading
 import traceback
 
-from flask import g
+from flask import g, redirect
 
 from sqlalchemy import or_, select
 from sqlalchemy.sql.expression import null, true
 
-import chellow.dloads
+from chellow.dloads import open_file
 from chellow.e.computer import SupplySource, forecast_date
-from chellow.models import Era, Session, Site, SiteEra, Supply
+from chellow.models import Era, RSession, Site, SiteEra, Supply
 from chellow.utils import (
     csv_make_val,
     hh_format,
@@ -19,22 +18,20 @@ from chellow.utils import (
     req_date,
     req_int,
 )
-from chellow.views import chellow_redirect
 
 
 def content(supply_id, start_date, finish_date, user):
     caches = {}
     f = None
     try:
-        with Session() as sess:
+        with RSession() as sess:
             supply = Supply.get_by_id(sess, supply_id)
 
             f_date = forecast_date()
 
-            running_name, finished_name = chellow.dloads.make_names(
-                f"supply_virtual_bills_hh_{supply_id}.csv", user
+            f = open_file(
+                f"supply_virtual_bills_hh_{supply_id}.csv", user, mode="w", newline=""
             )
-            f = open(running_name, mode="w", newline="")
             w = csv.writer(f, lineterminator="\n")
 
             mop_titles = []
@@ -155,7 +152,6 @@ def content(supply_id, start_date, finish_date, user):
     finally:
         if f is not None:
             f.close()
-            os.rename(running_name, finished_name)
 
 
 def do_get(sess):
@@ -165,4 +161,4 @@ def do_get(sess):
 
     args = supply_id, start_date, finish_date, g.user
     threading.Thread(target=content, args=args).start()
-    return chellow_redirect("/downloads", 303)
+    return redirect("/downloads", 303)
