@@ -1,17 +1,16 @@
 import csv
-import os
 import sys
 import threading
 import traceback
 from datetime import datetime as Datetime
 
-from flask import g, request
+from flask import g, redirect, request
 
 from sqlalchemy import or_
 from sqlalchemy.sql.expression import null, true
 
 import chellow.e.tnuos
-from chellow.dloads import make_names
+from chellow.dloads import open_file
 from chellow.e.computer import SupplySource, forecast_date
 from chellow.e.duos import duos_vb
 from chellow.models import Era, Pc, Session, Site, SiteEra, Source, Supply, User
@@ -24,7 +23,6 @@ from chellow.utils import (
     req_int,
     to_utc,
 )
-from chellow.views import chellow_redirect
 
 
 def _make_eras(sess, nov_start, year_finish, supply_id):
@@ -54,8 +52,7 @@ def content(year, supply_id, user_id):
     try:
         with Session() as sess:
             user = User.get_by_id(sess, user_id)
-            running_name, finished_name = make_names("supplies_triad.csv", user)
-            f = open(running_name, mode="w", newline="")
+            f = open_file("supplies_triad.csv", user, mode="w", newline="")
             writer = csv.writer(f, lineterminator="\n")
 
             march_start = to_utc(ct_datetime(year, 3, 1))
@@ -207,11 +204,10 @@ def content(year, supply_id, user_id):
     finally:
         if f is not None:
             f.close()
-            os.rename(running_name, finished_name)
 
 
 def do_get(sess):
     year = req_int("year")
     supply_id = req_int("supply_id") if "supply_id" in request.values else None
     threading.Thread(target=content, args=(year, supply_id, g.user.id)).start()
-    return chellow_redirect("/downloads", 303)
+    return redirect("/downloads", 303)
