@@ -1,5 +1,4 @@
 import csv
-import os
 import sys
 import threading
 import traceback
@@ -7,33 +6,48 @@ from collections import OrderedDict, defaultdict
 from datetime import datetime as Datetime
 from decimal import Decimal
 from itertools import combinations
+from numbers import Number
 
-from flask import g, request
+from flask import g, redirect, request
 
 from sqlalchemy import null, or_, select, true
 from sqlalchemy.orm import joinedload
 
 from werkzeug.exceptions import BadRequest
 
-import chellow.dloads
 import chellow.gas.engine
-from chellow.models import GBatch, GBill, GContract, GEra, Session, Site, SiteGEra, User
+from chellow.dloads import open_file
+from chellow.models import (
+    GBatch,
+    GBill,
+    GContract,
+    GEra,
+    RSession,
+    ReportRun,
+    Site,
+    SiteGEra,
+    User,
+)
 from chellow.utils import csv_make_val, hh_max, hh_min, req_date, req_int, to_utc
-from chellow.views import chellow_redirect
 
 
-def content(g_batch_id, g_bill_id, g_contract_id, start_date, finish_date, user_id):
+def content(
+    g_batch_id,
+    g_bill_id,
+    g_contract_id,
+    start_date,
+    finish_date,
+    user_id,
+    report_run_id,
+):
     forecast_date = to_utc(Datetime.max)
     report_context = {}
     sess = tmp_file = None
     try:
-        with Session() as sess:
+        with RSession() as sess:
             user = User.get_by_id(sess, user_id)
 
-            running_name, finished_name = chellow.dloads.make_names(
-                "g_bill_check.csv", user
-            )
-            tmp_file = open(running_name, "w")
+            tmp_file = open_file("g_bill_check.csv", user, mode="w")
             csv_writer = csv.writer(tmp_file)
             g_bills = (
                 select(GBill)
@@ -106,46 +120,62 @@ def content(g_batch_id, g_bill_id, g_contract_id, start_date, finish_date, user_
                     _process_g_bill_ids(
                         sess,
                         report_context,
+                        g_contract,
                         g_bill_ids,
                         forecast_date,
                         bill_titles,
                         vbf,
                         titles,
                         csv_writer,
+                        report_run_id,
                     )
+        ReportRun.w_update(report_run_id, "finished")
     except BadRequest as e:
         tmp_file.write(f"Problem: {e.description}")
+        ReportRun.w_update(report_run_id, "problem")
     except BaseException:
         msg = traceback.format_exc()
         sys.stderr.write(msg + "\n")
         tmp_file.write(f"Problem {msg}")
+        ReportRun.w_update(report_run_id, "interrupted")
     finally:
         tmp_file.close()
-        os.rename(running_name, finished_name)
 
 
 def _process_g_bill_ids(
     sess,
     report_context,
+    g_contract,
     g_bill_ids,
     forecast_date,
     bill_titles,
     vbf,
     titles,
     csv_writer,
+    report_run_id,
 ):
     g_bill_id = list(sorted(g_bill_ids))[0]
     g_bill_ids.remove(g_bill_id)
     g_bill = sess.query(GBill).filter(GBill.id == g_bill_id).one()
-    problem = ""
     g_supply = g_bill.g_supply
+    vals = {
+        "covered_vat_gbp": Decimal("0.00"),
+        "covered_net_gbp": Decimal("0.00"),
+        "covered_gross_gbp": Decimal("0.00"),
+        "covered_kwh": Decimal(0),
+        "covered_start": g_bill.start_date,
+        "covered_finish": g_bill.finish_date,
+        "covered_bill_ids": [],
+        "virtual_problem": "",
+    }
+    site_id = None
     read_dict = defaultdict(set)
     for g_read in g_bill.g_reads:
         if not all(
             g_read.msn == era.msn
             for era in g_supply.find_g_eras(sess, g_read.prev_date, g_read.pres_date)
         ):
-            problem += (
+            vals["virtual_problem"] += (
                 f"The MSN {g_read.msn} of the register read {g_read.id} doesn't match "
                 f"the MSN of all the relevant eras."
             )
@@ -157,17 +187,9 @@ def _process_g_bill_ids(
             typ_set = read_dict[str(dt) + "-" + g_read.msn]
             typ_set.add(typ)
             if len(typ_set) > 1:
-                problem += f" Reads taken on {dt} have differing read types."
-
-    vals = {
-        "covered_vat_gbp": Decimal("0.00"),
-        "covered_net_gbp": Decimal("0.00"),
-        "covered_gross_gbp": Decimal("0.00"),
-        "covered_kwh": Decimal(0),
-        "covered_start": g_bill.start_date,
-        "covered_finish": g_bill.finish_date,
-        "covered_bill_ids": [],
-    }
+                vals[
+                    "virtual_problem"
+                ] += f" Reads taken on {dt} have differing read types."
 
     covered_primary_bill = None
     enlarged = True
@@ -267,7 +289,7 @@ def _process_g_bill_ids(
                     else:
                         v = getattr(g_read, title)
                     vals[k].add(v)
-
+    elements = set()
     for g_era in sess.execute(
         select(GEra).where(
             GEra.g_supply == g_supply,
@@ -275,12 +297,20 @@ def _process_g_bill_ids(
             or_(GEra.finish_date == null(), GEra.finish_date >= vals["covered_start"]),
         )
     ).scalars():
+        if g_era.g_contract != g_contract:
+            vals[
+                "virtual_problem"
+            ] += "The contract of the bill is different from the contract of the era."
+            continue
         site = (
             sess.query(Site)
             .join(SiteGEra)
             .filter(SiteGEra.is_physical == true(), SiteGEra.g_era == g_era)
             .one()
         )
+        site_id = site.id
+        vals["site_code"] = site.code
+        vals["site_name"] = site.name
 
         chunk_start = hh_max(vals["covered_start"], g_era.start_date)
         chunk_finish = hh_min(vals["covered_finish"], g_era.finish_date)
@@ -309,6 +339,9 @@ def _process_g_bill_ids(
             except TypeError as detail:
                 raise BadRequest(f"For key {vk} and value {v}. {detail}")
 
+            if k.endswith("_gbp"):
+                elements.add(k[:-4])
+
     if g_bill.id not in covered_bills.keys():
         g_bill = covered_bills[sorted(covered_bills.keys())[0]]
 
@@ -319,27 +352,76 @@ def _process_g_bill_ids(
     vals["bill_finish_date"] = g_bill.finish_date
     vals["mprn"] = g_supply.mprn
     vals["supply_name"] = g_supply.name
-    vals["site_code"] = site.code
-    vals["site_name"] = site.name
-
-    for k, v in vals.items():
-        if k == "covered_bill_ids":
-            vals[k] = " | ".join(str(b) for b in v)
-        else:
-            vals[k] = csv_make_val(v)
 
     for i, title in enumerate(titles):
         if title.startswith("difference_"):
-            try:
-                covered_val = float(vals[titles[i - 2]])
-                virtual_val = float(vals[titles[i - 1]])
-                vals[title] = covered_val - virtual_val
-            except KeyError:
-                vals[title] = None
+            covered_val = float(vals.get(titles[i - 2], 0))
+            virtual_val = float(vals.get(titles[i - 1], 0))
+            vals[title] = covered_val - virtual_val
 
-    csv_writer.writerow(
-        [(vals.get(k) if vals.get(k) is not None else "") for k in titles]
-    )
+    csv_writer.writerow([csv_make_val(vals.get(k)) for k in titles])
+    vals["g_bill_id"] = g_bill.id
+    vals["g_batch_id"] = g_bill.g_batch.id
+    vals["g_supply_id"] = g_supply.id
+    vals["site_id"] = site_id
+    for element in sorted(elements):
+        for key in tuple(vals.keys()):
+            if not key.endswith("_gbp"):
+                covered_prefix = f"covered_{element}_"
+                virtual_prefix = f"virtual_{element}_"
+                if key.startswith(covered_prefix):
+                    part_name = key[len(covered_prefix) :]
+                elif key.startswith(virtual_prefix):
+                    part_name = key[len(virtual_prefix) :]
+                else:
+                    continue
+                virtual_part = vals.get(f"virtual_{element}_{part_name}", {0})
+                covered_part = vals.get(f"covered_{element}_{part_name}", {0})
+                if isinstance(virtual_part, set) and len(virtual_part) == 1:
+                    virtual_part = float(next(iter(virtual_part)))
+                if isinstance(covered_part, set) and len(covered_part) == 1:
+                    covered_part = float(next(iter(covered_part)))
+
+                if isinstance(virtual_part, Number) and isinstance(
+                    covered_part, Number
+                ):
+                    diff = float(covered_part) - float(virtual_part)
+                else:
+                    diff = 0
+
+                vals[f"difference_{element}_{part_name}"] = diff
+
+    for suffix in (
+        "kwh",
+        "units_consumed",
+    ):
+        try:
+            covered = float(vals[f"covered_{suffix}"])
+            virtual = float(vals[f"virtual_{suffix}"])
+            vals[f"difference_{suffix}"] = covered - virtual
+        except KeyError:
+            vals[f"difference_{suffix}"] = 0
+
+    for prefix in (
+        "correction_factor",
+        "unit_code",
+        "calorific_value",
+    ):
+        covered = vals.get(f"covered_{prefix}", [0])
+        virtual = vals.get(f"virtual_{prefix}", [0])
+        if len(covered) == 1 and len(virtual) == 1:
+            if covered == virtual:
+                diff = 0
+            else:
+                try:
+                    diff = float(next(iter(covered))) - float(next(iter(virtual)))
+                except ValueError:
+                    diff = False
+        else:
+            diff = False
+        vals[f"difference_{prefix}"] = diff
+
+    ReportRun.w_insert_row(report_run_id, "", titles, vals, {"is_checked": False})
 
 
 def do_get(sess):
@@ -347,17 +429,39 @@ def do_get(sess):
 
     if "g_batch_id" in request.values:
         g_batch_id = req_int("g_batch_id")
+        g_batch = GBatch.get_by_id(g.sess, g_batch_id)
+        run_g_contract_id = g_batch.g_contract.id
     elif "g_bill_id" in request.values:
         g_bill_id = req_int("g_bill_id")
+        g_bill = GBill.get_by_id(g.sess, g_bill_id)
+        run_g_contract_id = g_bill.g_batch.g_contract.id
     elif "g_contract_id" in request.values:
         g_contract_id = req_int("g_contract_id")
         start_date = req_date("start_date")
         finish_date = req_date("finish_date")
+        run_g_contract_id = g_contract_id
     else:
         raise BadRequest(
             "The bill check needs a g_batch_id, g_bill_id or g_contract_id."
         )
 
-    args = g_batch_id, g_bill_id, g_contract_id, start_date, finish_date, g.user.id
+    report_run = ReportRun.insert(
+        sess,
+        "g_bill_check",
+        g.user,
+        "g_bill_check",
+        {"g_contract_id": run_g_contract_id},
+    )
+    sess.commit()
+
+    args = (
+        g_batch_id,
+        g_bill_id,
+        g_contract_id,
+        start_date,
+        finish_date,
+        g.user.id,
+        report_run.id,
+    )
     threading.Thread(target=content, args=args).start()
-    return chellow_redirect("/downloads", 303)
+    return redirect(f"/report_runs/{report_run.id}", 303)
