@@ -1,10 +1,9 @@
 import csv
-import os
 import sys
 import threading
 import traceback
 
-from flask import g
+from flask import g, redirect
 
 import requests
 
@@ -14,7 +13,7 @@ from sqlalchemy.sql.expression import null, or_
 
 from werkzeug.exceptions import BadRequest
 
-import chellow.dloads
+from chellow.dloads import open_file
 from chellow.models import (
     Contract,
     Era,
@@ -26,8 +25,7 @@ from chellow.models import (
     Supply,
     User,
 )
-from chellow.utils import req_bool
-from chellow.views import chellow_redirect
+from chellow.utils import csv_make_val, req_bool, utc_datetime_now
 
 
 FNAME = "ecoes_comparison"
@@ -46,10 +44,7 @@ def content(user_id, show_ignored, report_run_id):
     try:
         with Session() as sess:
             user = User.get_by_id(sess, user_id)
-            running_name, finished_name = chellow.dloads.make_names(
-                f"{FNAME}.csv", user
-            )
-            f = open(running_name, mode="w", newline="")
+            f = open_file(f"{FNAME}.csv", user, mode="w", newline="")
             report_run = ReportRun.get_by_id(sess, report_run_id)
 
             props = Contract.get_non_core_by_name(
@@ -68,7 +63,6 @@ def content(user_id, show_ignored, report_run_id):
             for key in (
                 "user_name",
                 "password",
-                "prefix",
                 "exclude_mpan_cores",
                 "ignore_mpan_cores_msn",
             ):
@@ -82,7 +76,7 @@ def content(user_id, show_ignored, report_run_id):
 
             exclude_mpan_cores = ecoes_props["exclude_mpan_cores"]
             ignore_mpan_cores_msn = ecoes_props["ignore_mpan_cores_msn"]
-            url_prefix = ecoes_props["prefix"]
+            url_prefix = "https://www.ecoes.co.uk/"
 
             proxies = props.get("proxies", {})
             s = requests.Session()
@@ -140,7 +134,6 @@ def content(user_id, show_ignored, report_run_id):
     finally:
         if f is not None:
             f.close()
-            os.rename(running_name, finished_name)
 
 
 def _process(
@@ -153,6 +146,7 @@ def _process(
     report_run,
 ):
     writer = csv.writer(f, lineterminator="\n")
+    now = utc_datetime_now()
 
     mpans = []
 
@@ -231,9 +225,12 @@ def _process(
         ecoes_row["mpan_spaces"] = mpan_spaces
         if mpan_spaces in ecoes_mpans:
             prev_row = ecoes_mpans[mpan_spaces]
-            prev_row["meter_count"] += 1
+            msn = ecoes_row["msn"]
+            if len(msn) > 0:
+                prev_msns = prev_row["msn"].split(",")
+                prev_msns.append(msn)
+                prev_row["msn"] = ", ".join(prev_msns)
         else:
-            ecoes_row["meter_count"] = 1
             ecoes_mpans[mpan_spaces] = ecoes_row
 
     titles = (
@@ -242,25 +239,30 @@ def _process(
         "ecoes_pc",
         "chellow_pc",
         "ecoes_mtc",
+        "ecoes_mtc_date",
         "chellow_mtc",
         "ecoes_llfc",
+        "ecoes_llfc_from",
         "chellow_llfc",
         "ecoes_ssc",
         "chellow_ssc",
         "ecoes_es",
         "chellow_es",
         "ecoes_supplier",
+        "ecoes_supplier_registration_from",
         "chellow_supplier",
         "chellow_supplier_contract_name",
         "ecoes_dc",
         "chellow_dc",
         "ecoes_mop",
+        "ecoes_mop_appoint_date",
         "chellow_mop",
         "ecoes_gsp_group",
+        "ecoes_gsp_effective_from",
         "chellow_gsp_group",
         "ecoes_msn",
-        "chellow_msn",
         "ecoes_msn_install_date",
+        "chellow_msn",
         "ecoes_meter_type",
         "chellow_meter_type",
         "ignored",
@@ -273,6 +275,7 @@ def _process(
         chellow_pc = ""
         chellow_mtc = ""
         chellow_llfc = ""
+        chellow_llfc_desc = ""
         chellow_ssc = ""
         chellow_es = ""
         chellow_supplier = ""
@@ -286,6 +289,11 @@ def _process(
         chellow_supply_id = None
         chellow_era_id = None
         ignore = True
+        ecoes_dno_code = ecoes["mpan-core"][:2]
+        ecoes_dno = Party.get_dno_by_code(sess, ecoes_dno_code, now)
+        ecoes_llfc_desc = ""
+        chellow_site_code = ""
+        chellow_site_name = ""
         diffs = []
 
         try:
@@ -296,15 +304,6 @@ def _process(
         ecoes_disconnected = ecoes_es == ""
         current_chell = mpan_spaces in mpans
 
-        if ecoes["meter_count"] > 1:
-            problem += (
-                f"There are {ecoes['meter_count']} meters associated with this MPAN "
-                f"core in ECOES, but Chellow only supports one meter per supply at the "
-                f"moment. If there really should be multiple meters for this supply, "
-                f"let me know and I'll add support for it in Chellow."
-            )
-            ignore = False
-
         if ecoes_disconnected and current_chell:
             problem += "Disconnected in ECOES, but current in Chellow. "
             ignore = False
@@ -337,40 +336,44 @@ def _process(
 
         if current_chell:
             mpans.remove(mpan_spaces)
-            era = sess.execute(
-                select(Era)
-                .filter(
-                    Era.finish_date == null(),
-                    or_(
-                        Era.imp_mpan_core == mpan_spaces,
-                        Era.exp_mpan_core == mpan_spaces,
-                    ),
+            era = (
+                sess.scalars(
+                    select(Era)
+                    .where(
+                        Era.finish_date == null(),
+                        or_(
+                            Era.imp_mpan_core == mpan_spaces,
+                            Era.exp_mpan_core == mpan_spaces,
+                        ),
+                    )
+                    .options(
+                        joinedload(Era.supply).joinedload(Supply.gsp_group),
+                        joinedload(Era.mop_contract)
+                        .joinedload(Contract.party)
+                        .joinedload(Party.participant),
+                        joinedload(Era.dc_contract)
+                        .joinedload(Contract.party)
+                        .joinedload(Party.participant),
+                        joinedload(Era.imp_supplier_contract)
+                        .joinedload(Contract.party)
+                        .joinedload(Party.participant),
+                        joinedload(Era.exp_supplier_contract)
+                        .joinedload(Contract.party)
+                        .joinedload(Party.participant),
+                        joinedload(Era.pc),
+                        joinedload(Era.imp_llfc),
+                        joinedload(Era.exp_llfc),
+                        joinedload(Era.mtc_participant).joinedload(
+                            MtcParticipant.meter_type
+                        ),
+                        joinedload(Era.ssc),
+                        joinedload(Era.energisation_status),
+                        joinedload(Era.channels),
+                    )
                 )
-                .options(
-                    joinedload(Era.supply).joinedload(Supply.gsp_group),
-                    joinedload(Era.mop_contract)
-                    .joinedload(Contract.party)
-                    .joinedload(Party.participant),
-                    joinedload(Era.dc_contract)
-                    .joinedload(Contract.party)
-                    .joinedload(Party.participant),
-                    joinedload(Era.imp_supplier_contract)
-                    .joinedload(Contract.party)
-                    .joinedload(Party.participant),
-                    joinedload(Era.exp_supplier_contract)
-                    .joinedload(Contract.party)
-                    .joinedload(Party.participant),
-                    joinedload(Era.pc),
-                    joinedload(Era.imp_llfc),
-                    joinedload(Era.exp_llfc),
-                    joinedload(Era.mtc_participant).joinedload(
-                        MtcParticipant.meter_type
-                    ),
-                    joinedload(Era.ssc),
-                    joinedload(Era.energisation_status),
-                    joinedload(Era.channels),
-                )
-            ).scalar()
+                .unique()
+                .one()
+            )
             chellow_supply_id = era.supply.id
             chellow_era_id = era.id
             chellow_es = era.energisation_status.code
@@ -408,11 +411,17 @@ def _process(
                     ignore = False
 
                 chellow_llfc = llfc.code
-                if ecoes["llfc"].zfill(3) != chellow_llfc:
+                chellow_llfc_desc = llfc.description
+                ecoes_llfc_code = ecoes["llfc"].zfill(3)
+                if ecoes_llfc_code != chellow_llfc:
                     problem += "The LLFCs don't match. "
                     ignore = False
                     diffs.append("llfc")
 
+                ecoes_llfc = ecoes_dno.find_llfc_by_code(sess, ecoes_llfc_code, now)
+                if ecoes_llfc is not None:
+                    ecoes_llfc_desc = ecoes_llfc.description
+
                 chellow_ssc = era.ssc
                 if chellow_ssc is None:
                     chellow_ssc = ""
@@ -442,8 +451,9 @@ def _process(
                     diffs.append("supplier")
 
                 dc_contract = era.dc_contract
-                if dc_contract is None:
-                    chellow_dc = ""
+                chellow_dc_props = dc_contract.make_properties()
+                if "nhh_participant" in chellow_dc_props:
+                    chellow_dc = chellow_dc_props["nhh_participant"]
                 else:
                     chellow_dc = dc_contract.party.participant.code
 
@@ -469,11 +479,15 @@ def _process(
                     ignore = False
                     diffs.append("gsp_group")
 
-                chellow_msn = era.msn
-                if chellow_msn is None:
-                    chellow_msn = ""
+                chellow_site = era.get_physical_site(sess)
+                chellow_site_code = chellow_site.code
+                chellow_site_name = chellow_site.name
 
-                if chellow_msn != ecoes["msn"]:
+                chellow_msn = era.msn
+
+                if set([m.strip() for m in chellow_msn.split(",")]) != set(
+                    [m.strip() for m in ecoes["msn"].split(",")]
+                ):
                     problem += "The meter serial numbers don't match. "
                     diffs.append("msn")
                     if mpan_spaces not in ignore_mpan_cores_msn:
@@ -484,7 +498,11 @@ def _process(
                         "serial numbers do match. "
                     )
 
-                chellow_meter_type = _meter_type(era)
+                chellow_dtc_meter_type = era.dtc_meter_type
+                if chellow_dtc_meter_type is None:
+                    chellow_meter_type = ""
+                else:
+                    chellow_meter_type = chellow_dtc_meter_type.code
 
                 if chellow_meter_type != ecoes["meter-type"]:
                     problem += "The DTC meter types don't match."
@@ -492,17 +510,20 @@ def _process(
                     diffs.append("meter_type")
 
         if len(problem) > 0 and not (not show_ignored and ignore):
+            address_lines = [ecoes[f"address-line-{i}"] for i in range(1, 10)]
             values = {
                 "mpan_core": mpan_spaces,
                 "mpan_core_no_spaces": ecoes["mpan-core"],
                 "ecoes_pc": ecoes["pc"],
                 "chellow_pc": chellow_pc,
                 "ecoes_mtc": ecoes["mtc"],
+                "ecoes_mtc_date": _parse_date(ecoes["mtc-date"]),
                 "chellow_mtc": chellow_mtc,
-                "chellow_mtc_date": _parse_date(ecoes["mtc-date"]),
                 "ecoes_llfc": ecoes["llfc"],
+                "ecoes_llfc_desc": ecoes_llfc_desc,
                 "ecoes_llfc_from": _parse_date(ecoes["llfc-from"]),
                 "chellow_llfc": chellow_llfc,
+                "chellow_llfc_desc": chellow_llfc_desc,
                 "ecoes_ssc": ecoes["ssc"],
                 "chellow_ssc": chellow_ssc,
                 "ecoes_es": ecoes["energisation-status"],
@@ -528,15 +549,19 @@ def _process(
                 "chellow_meter_type": chellow_meter_type,
                 "ignored": ignore,
                 "problem": problem,
+                "address": ", ".join(
+                    [a for a in address_lines if len(a) > 0 and a != "NULL"]
+                ),
+                "chellow_site_code": chellow_site_code,
+                "chellow_site_name": chellow_site_name,
             }
-            writer.writerow(values[t] for t in titles)
+            writer.writerow(csv_make_val(values[t]) for t in titles)
             values["chellow_supplier_contract_id"] = chellow_supplier_contract_id
             values["chellow_supply_id"] = chellow_supply_id
             values["diffs"] = diffs
             values["chellow_era_id"] = chellow_era_id
             report_run.insert_row(sess, "", titles, values, {})
             sess.commit()
-        sess.expunge_all()
 
     for mpan_core in mpans:
         supply = Supply.get_by_mpan_core(sess, mpan_core)
@@ -560,7 +585,8 @@ def _process(
 
         msn = "" if era.msn is None else era.msn
 
-        meter_type = _meter_type(era)
+        dtc_meter_type = era.dtc_meter_type
+        meter_type = "" if dtc_meter_type is None else dtc_meter_type.code
 
         values = {
             "mpan_core": mpan_core,
@@ -568,21 +594,26 @@ def _process(
             "ecoes_pc": "",
             "chellow_pc": era.pc.code,
             "ecoes_mtc": "",
+            "ecoes_mtc_date": "",
             "chellow_mtc": era.mtc_participant.mtc.code,
             "ecoes_llfc": "",
+            "ecoes_llfc_from": "",
             "chellow_llfc": llfc.code,
             "ecoes_ssc": "",
             "chellow_ssc": ssc,
             "ecoes_es": "",
             "chellow_es": es,
             "ecoes_supplier": "",
+            "ecoes_supplier_registration_from": "",
             "chellow_supplier": supplier_contract.party.participant.code,
             "chellow_supplier_contract_name": supplier_contract.name,
             "ecoes_dc": "",
             "chellow_dc": dc,
             "ecoes_mop": "",
+            "ecoes_mop_appoint_date": "",
             "chellow_mop": mop,
             "ecoes_gsp_group": "",
+            "ecoes_gsp_effective_from": "",
             "chellow_gsp_group": supply.gsp_group.code,
             "ecoes_msn": "",
             "chellow_msn": msn,
@@ -592,7 +623,7 @@ def _process(
             "ignored": False,
             "problem": "In Chellow, but not in ECOES.",
         }
-        writer.writerow(values[t] for t in titles)
+        writer.writerow(csv_make_val(values[t]) for t in titles)
         values["chellow_supplier_contract_id"] = supplier_contract.id
         values["chellow_supply_id"] = era.supply.id
         values["diffs"] = []
@@ -600,21 +631,6 @@ def _process(
         report_run.insert_row(sess, "", titles, values, {})
 
 
-def _meter_type(era):
-    props = era.props
-    try:
-        return props["meter_type"]
-    except KeyError:
-        if era.pc.code == "00":
-            return "H"
-        elif len(era.channels) > 0:
-            return "RCAMR"
-        elif era.mtc_participant.meter_type.code in ["UM", "PH"]:
-            return ""
-        else:
-            return "N"
-
-
 def do_get(sess):
     show_ignored = req_bool("show_ignored")
     report_run = ReportRun.insert(
@@ -627,4 +643,4 @@ def do_get(sess):
     sess.commit()
     args = g.user.id, show_ignored, report_run.id
     threading.Thread(target=content, args=args).start()
-    return chellow_redirect(f"/report_runs/{report_run.id}", 303)
+    return redirect(f"/report_runs/{report_run.id}", 303)
