@@ -1,33 +1,23 @@
 import csv
-import os
 import sys
 import threading
 import traceback
 
-from flask import g, request
+from flask import g, redirect, request
 
 from sqlalchemy import or_
 from sqlalchemy.orm import joinedload
 from sqlalchemy.sql.expression import null
 
-from werkzeug.exceptions import BadRequest
-
-import chellow.dloads
-from chellow.e.computer import contract_func
-from chellow.gas.engine import GDataSource, forecast_date
+from chellow.dloads import open_file
 from chellow.models import GEra, GSupply, Session
 from chellow.utils import csv_make_val, req_date, req_int
-from chellow.views import chellow_redirect
 
 
 def content(date, g_supply_id, user):
     try:
-        running_name, finished_name = chellow.dloads.make_names(
-            "g_supplies_snapshot.csv", user
-        )
-
         with Session() as sess:
-            f = open(running_name, mode="w", newline="")
+            f = open_file("g_supplies_snapshot.csv", user, mode="w", newline="")
             writer = csv.writer(f, lineterminator="\n")
             writer.writerow(
                 (
@@ -50,8 +40,6 @@ def content(date, g_supply_id, user):
                     "soq",
                 )
             )
-            fdate = forecast_date()
-            caches = {}
 
             g_eras = (
                 sess.query(GEra, GSupply)
@@ -89,16 +77,7 @@ def content(date, g_supply_id, user):
                 g_supply_start_date = sup_g_eras[0].start_date
                 g_supply_finish_date = sup_g_eras[-1].finish_date
 
-                ds = GDataSource(sess, date, date, fdate, g_era, caches, None)
                 g_supplier_contract = g_era.g_contract
-                vb_function = contract_func(caches, g_supplier_contract, "virtual_bill")
-                if vb_function is None:
-                    raise BadRequest(
-                        f"The contract {g_supplier_contract.name} doesn't have the "
-                        f"virtual_bill() function."
-                    )
-                vb_function(ds)
-                bill = ds.bill
 
                 writer.writerow(
                     csv_make_val(value)
@@ -118,8 +97,8 @@ def content(date, g_supply_id, user):
                         g_supply_start_date,
                         g_supply_finish_date,
                         g_era.g_reading_frequency.code,
-                        bill["aq"],
-                        bill["soq"],
+                        g_era.aq,
+                        g_era.soq,
                     ]
                 )
     except BaseException:
@@ -129,7 +108,6 @@ def content(date, g_supply_id, user):
     finally:
         if f is not None:
             f.close()
-            os.rename(running_name, finished_name)
 
 
 def do_get(session):
@@ -142,4 +120,4 @@ def do_get(session):
 
     args = (date, g_supply_id, user)
     threading.Thread(target=content, args=args).start()
-    return chellow_redirect("/downloads", 303)
+    return redirect("/downloads", 303)
