@@ -1,22 +1,20 @@
-import os
 import sys
 import threading
 import traceback
 
 
-from flask import g, request
+from flask import g, redirect, request
 
-import odio
+from odio import create_spreadsheet
 
 from sqlalchemy import select
 from sqlalchemy.orm import joinedload
 
 from werkzeug.exceptions import BadRequest
 
-import chellow.dloads
+from chellow.dloads import open_file
 from chellow.models import MeasurementRequirement, Session, Ssc, Tpr, User
 from chellow.utils import req_bool
-from chellow.views import chellow_redirect
 
 
 def write_spreadsheet(
@@ -28,10 +26,10 @@ def write_spreadsheet(
 ):
     fl.seek(0)
     fl.truncate()
-    with odio.create_spreadsheet(fl, "1.2", compressed=compressed) as f:
-        f.append_table("SSCs", ssc_rows)
-        f.append_table("MRs", mr_rows)
-        f.append_table("TPRs", tpr_rows)
+    with create_spreadsheet(fl, compressed=compressed) as sheet:
+        sheet.append_table("SSCs", ssc_rows)
+        sheet.append_table("MRs", mr_rows)
+        sheet.append_table("TPRs", tpr_rows)
 
 
 def content(
@@ -54,9 +52,7 @@ def content(
         with Session() as sess:
             user = User.get_by_id(sess, user_id)
 
-            running_name, finished_name = chellow.dloads.make_names("sscs.ods", user)
-
-            rf = open(running_name, "wb")
+            rf = open_file("sscs.ods", user, "wb")
 
             for ssc in sess.scalars(select(Ssc).order_by(Ssc.code)):
                 ssc_rows.append(
@@ -100,8 +96,7 @@ def content(
         ssc_rows.append(["Problem " + msg])
         if rf is None:
             msg = traceback.format_exc()
-            r_name, f_name = chellow.dloads.make_names("error.txt", None)
-            ef = open(r_name, "w")
+            ef = open_file("error.txt", None, "w")
             ef.write(msg + "\n")
             ef.close()
         else:
@@ -109,7 +104,6 @@ def content(
     finally:
         if rf is not None:
             rf.close()
-            os.rename(running_name, finished_name)
 
 
 def do_get(sess):
@@ -119,4 +113,4 @@ def do_get(sess):
 
     args = (user.id, compression)
     threading.Thread(target=content, args=args).start()
-    return chellow_redirect("/downloads", 303)
+    return redirect("/downloads", 303)
