@@ -124,9 +124,7 @@ def test_process_BTL_zeroes(sess):
         utc_datetime(2000, 1, 31, 23, 30),
         gsp_group,
         mop_contract,
-        "773",
         dc_contract,
-        "ghyy3",
         "hgjeyhuw",
         dno,
         pc,
@@ -308,9 +306,7 @@ def test_process_BTL_non_zeroes(sess):
         utc_datetime(2000, 1, 31, 23, 30),
         gsp_group,
         mop_contract,
-        "773",
         dc_contract,
-        "ghyy3",
         "hgjeyhuw",
         dno,
         pc,
@@ -509,9 +505,7 @@ def test_process_BTL_multiple_charges_one_tpr(sess):
         utc_datetime(2000, 1, 31, 23, 30),
         gsp_group,
         mop_contract,
-        "773",
         dc_contract,
-        "ghyy3",
         "hgjeyhuw",
         dno,
         pc,
@@ -769,9 +763,7 @@ def test_process_BTL_unmetered(sess):
         utc_datetime(2000, 1, 31, 23, 30),
         gsp_group,
         mop_contract,
-        "773",
         dc_contract,
-        "ghyy3",
         "hgjeyhuw",
         dno,
         pc,
