@@ -112,9 +112,7 @@ def test_SiteSource_init_hh_data(sess, mocker):
         None,
         gsp_group,
         mop_contract,
-        "773",
         dc_contract,
-        "ghyy3",
         "hgjeyhuw",
         dno,
         pc,
@@ -411,9 +409,7 @@ def test_init_hh_data(sess, mocker):
         None,
         gsp_group,
         mop_contract,
-        "773",
         dc_contract,
-        "ghyy3",
         "hgjeyhuw",
         dno,
         pc,
@@ -582,9 +578,7 @@ def test_init_hh_data_export(sess, mocker):
         None,
         gsp_group,
         mop_contract,
-        "773",
         dc_contract,
-        "ghyy3",
         "hgjeyhuw",
         dno,
         pc,
@@ -772,9 +766,7 @@ def test_SupplySource_init_hh(sess, mocker):
         None,
         gsp_group,
         mop_contract,
-        "773",
         dc_contract,
-        "ghyy3",
         "hgjeyhuw",
         dno,
         pc,
@@ -959,9 +951,7 @@ def test_SupplySource_init_nhh(sess, mocker):
         None,
         gsp_group,
         mop_contract,
-        "773",
         dc_contract,
-        "ghyy3",
         "hgjeyhuw",
         dno,
         pc,
@@ -1075,9 +1065,7 @@ def test_SupplySource_init_era_maps(sess, mocker):
         None,
         gsp_group,
         mop_contract,
-        "773",
         dc_contract,
-        "ghyy3",
         "hgjeyhuw",
         dno,
         pc,
@@ -1293,9 +1281,7 @@ def virtual_bill(ds):
         None,
         gsp_group,
         mop_contract,
-        "773",
         dc_contract,
-        "ghyy3",
         "hgjeyhuw",
         dno,
         pc,
