@@ -110,9 +110,7 @@ def test_duos_vb_unmetered(sess):
         utc_datetime(2000, 1, 31, 23, 30),
         gsp_group,
         mop_contract,
-        "773",
         dc_contract,
-        "ghyy3",
         "hgjeyhuw",
         dno,
         pc,
@@ -728,9 +726,7 @@ def test_SiteSource(sess):
         None,
         gsp_group,
         mop_contract,
-        "773",
         dc_contract,
-        "ghyy3",
         "hgjeyhuw",
         dno,
         pc,
