@@ -105,9 +105,7 @@ def test_content(mocker, sess):
         None,
         gsp_group,
         mop_contract,
-        "773",
         dc_contract,
-        "ghyy3",
         "hgjeyhuw",
         dno,
         pc,
@@ -231,9 +229,7 @@ def test_process_2010(mocker, sess):
         None,
         gsp_group,
         mop_contract,
-        "773",
         dc_contract,
-        "ghyy3",
         "hgjeyhuw",
         dno,
         pc,
@@ -291,9 +287,7 @@ def test_process_2010(mocker, sess):
             "Energisation Status",
             "Number Of Registers",
             "MOP Contract",
-            "Mop Account",
             "DC Contract",
-            "DC Account",
             "Meter Serial Number",
             "Meter Installation Date",
             "Latest Normal Meter Read Date",
@@ -351,9 +345,7 @@ def test_process_2010(mocker, sess):
             "E",
             "",
             "Fusion",
-            "773",
             "Fusion DC 2000",
-            "ghyy3",
             "hgjeyhuw",
             "2000-01-01 00:00",
             "hh",
@@ -487,9 +479,7 @@ def test_process_2024(mocker, sess):
         None,
         gsp_group,
         mop_contract,
-        "773",
         dc_contract,
-        "ghyy3",
         "hgjeyhuw",
         dno,
         pc,
@@ -547,9 +537,7 @@ def test_process_2024(mocker, sess):
             "Energisation Status",
             "Number Of Registers",
             "MOP Contract",
-            "Mop Account",
             "DC Contract",
-            "DC Account",
             "Meter Serial Number",
             "Meter Installation Date",
             "Latest Normal Meter Read Date",
@@ -607,9 +595,7 @@ def test_process_2024(mocker, sess):
             "E",
             "",
             "Fusion",
-            "773",
             "Fusion DC 2000",
-            "ghyy3",
             "hgjeyhuw",
             "2000-01-01 00:00",
             "hh",
