@@ -589,9 +589,7 @@ def test_general_import_era_insert(sess):
         None,
         gsp_group,
         mop_contract,
-        "773",
         dc_contract,
-        "ghyy3",
         "hgjeyhuw",
         dno,
         pc,
@@ -641,8 +639,6 @@ def test_general_import_era_insert(sess):
         "{no change}",
         "{no change}",
         "{no change}",
-        "{no change}",
-        "{no change}",
         "Fusion Supplier 2000",
         "{no change}",
         "{no change}",
@@ -725,9 +721,7 @@ def test_general_import_era_insert_nhh_no_change(sess):
         None,
         gsp_group,
         mop_contract,
-        "773",
         dc_contract,
-        "ghyy3",
         "hgjeyhuw",
         dno,
         pc,
@@ -861,9 +855,7 @@ def test_general_import_era_insert_nhh_change(sess):
         None,
         gsp_group,
         mop_contract,
-        "773",
         dc_contract,
-        "ghyy3",
         "hgjeyhuw",
         dno,
         pc,
@@ -899,8 +891,6 @@ def test_general_import_era_insert_nhh_change(sess):
         "{no change}",
         "{no change}",
         "{no change}",
-        "{no change}",
-        "{no change}",
         ssc_code,
         "{no change}",
         "{no change}",
@@ -991,9 +981,7 @@ def test_general_import_era_update_hh(sess):
         None,
         gsp_group,
         mop_contract,
-        "773",
         dc_contract,
-        "ghyy3",
         "hgjeyhuw",
         dno,
         pc,
@@ -1119,9 +1107,7 @@ def test_general_import_era_update_nhh(sess):
         None,
         gsp_group,
         mop_contract,
-        "773",
         dc_contract,
-        "ghyy3",
         "hgjeyhuw",
         dno,
         pc,
@@ -1402,9 +1388,7 @@ def test_general_import_supply_insert_HH(sess):
         hh_format(start_date),
         "",
         mop_contract_name,
-        "22 7867 6232 781",
         dc_contract_name,
-        "22 7867 6232 781",
         msn,
         "22",
         "00",
@@ -1508,9 +1492,7 @@ def test_general_import_supply_insert_NHH(sess):
         hh_format(start_date),
         "",
         mop_contract_name,
-        "22 7867 6232 781",
         dc_contract_name,
-        "22 7867 6232 781",
         msn,
         "22",
         pc_code,
