@@ -129,9 +129,7 @@ def test_Bill_update(sess):
         None,
         gsp_group,
         mop_contract,
-        "773",
         dc_contract,
-        "ghyy3",
         "e1msn",
         dno,
         pc,
@@ -239,9 +237,7 @@ def test_Bill_insert_read_duplicate(sess):
         utc_datetime(2020, 1, 31),
         gsp_group,
         mop_contract,
-        "773",
         dc_contract,
-        "ghyy3",
         "hgjeyhuw",
         dno,
         pc,
@@ -374,9 +370,7 @@ def test_Channel_delete_data(sess):
         None,
         gsp_group,
         mop_contract,
-        "773",
         dc_contract,
-        "ghyy3",
         "e1msn",
         dno,
         pc,
@@ -475,9 +469,7 @@ def test_Era_update(sess):
         None,
         gsp_group,
         mop_contract,
-        "773",
         dc_contract,
-        "ghyy3",
         "e1msn",
         dno,
         pc,
@@ -505,9 +497,7 @@ def test_Era_update(sess):
         era.start_date,
         None,
         mop_contract,
-        "379540",
         dc_contract,
-        "547yt",
         msn,
         pc,
         "845",
@@ -613,9 +603,7 @@ def test_Era_meter_category_dumb(sess):
         None,
         gsp_group,
         mop_contract,
-        "773",
         dc_contract,
-        "ghyy3",
         "e1msn",
         dno,
         pc,
@@ -836,9 +824,7 @@ def test_Era_init_llfc_valid_to(sess):
             to_utc(ct_datetime(2011, 1, 1)),
             gsp_group,
             mop_contract,
-            "773",
             dc_contract,
-            "ghyy3",
             "e1msn",
             dno,
             pc,
@@ -1014,9 +1000,7 @@ def test_Site_hh_check(sess):
         utc_datetime(2020, 1, 31),
         gsp_group,
         mop_contract,
-        "773",
         dc_contract,
-        "ghyy3",
         "hgjeyhuw",
         dno,
         pc,
@@ -1171,9 +1155,7 @@ def test_Supply_insert_era_at(sess):
         None,
         gsp_group,
         mop_contract,
-        "773",
         dc_contract,
-        "ghyy3",
         era1_msn,
         dno,
         pc,
@@ -1203,9 +1185,7 @@ def test_Supply_insert_era_at(sess):
         era2_start_date,
         None,
         mop_contract,
-        "379540",
         dc_contract,
-        "547yt",
         era2_msn,
         pc,
         "845",
@@ -1308,9 +1288,7 @@ def test_Supply_insert_era_at_nhh(sess):
         None,
         gsp_group,
         mop_contract,
-        "773",
         dc_contract,
-        "ghyy3",
         era1_msn,
         dno,
         pc,
@@ -1412,9 +1390,7 @@ def test_Supply_insert_era_at_hh_data(sess):
         None,
         gsp_group,
         mop_contract,
-        "773",
         dc_contract,
-        "ghyy3",
         era1_msn,
         dno,
         pc,
