@@ -286,9 +286,7 @@ def test_site_get(client, sess):
         utc_datetime(2020, 1, 1),
         gsp_group,
         mop_contract,
-        "773",
         dc_contract,
-        "ghyy3",
         "hgjeyhuw",
         dno,
         pc,
@@ -431,9 +429,7 @@ def test_site_get_dumb(client, sess):
         utc_datetime(2020, 1, 1),
         gsp_group,
         mop_contract,
-        "773",
         dc_contract,
-        "ghyy3",
         "hgjeyhuw",
         dno,
         pc,
@@ -574,9 +570,7 @@ def test_supplies_get_e(sess, client):
         utc_datetime(2020, 1, 1),
         gsp_group,
         mop_contract,
-        "773",
         dc_contract,
-        "ghyy3",
         "hgjeyhuw",
         dno,
         pc,
@@ -606,9 +600,7 @@ def test_supplies_get_e(sess, client):
         utc_datetime(2020, 1, 1),
         gsp_group,
         mop_contract,
-        "773",
         dc_contract,
-        "ghyy3",
         "hgjeyhuw",
         dno,
         pc,
@@ -803,9 +795,7 @@ def test_general_import_post_full(sess, client):
         utc_datetime(2020, 1, 1),
         gsp_group,
         mop_contract,
-        "773",
         dc_contract,
-        "ghyy3",
         "hgjeyhuw",
         dno,
         pc,
